// Copyright 2019 The Hugo Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package hugolib

import (
	"testing"

	qt "github.com/frankban/quicktest"
	"github.com/gohugoio/hugo/resources/page"
)

func TestUnwrapPage(t *testing.T) {
	c := qt.New(t)

	p := &pageState{}

	c.Assert(mustUnwrap(newPageForShortcode(p)), qt.Equals, p)
	c.Assert(mustUnwrap(newPageForRenderHook(p)), qt.Equals, p)
}

func mustUnwrap(v interface{}) page.Page {
	p, err := unwrapPage(v)
	if err != nil {
		panic(err)
	}
	return p
}
